@@ -30,7 +30,31 @@
   # parsing, if the object is in that environment lock it and then
   # unlock on exit
   .udfEnvSet(list(parent.frame(1), parent.frame(2)))
-  rxUiGet(.uiToRxUiGet(obj=obj, arg=arg, exact=exact))
+  .obj <- .uiToRxUiGet(obj=obj, arg=arg, exact=exact)
+  if (.rstudioComplete()){
+    # If Rstudio is running completion, then we need to simply
+    # return a dummy object so it doesn't calculate the value.
+    #
+    # However, if the object actually exists, then use the rxUiGet.default method
+    # to get the value.
+    .v <- as.character(utils::methods("rxUiGet"))
+    .cls <- class(.obj)[1]
+    .method <- paste0("rxUiGet.", .cls)
+    if (.method %in% .v) {
+      # If there is a rstudio value in the method, assume that is what you
+      # wish to return for the rstudio auto-completion method
+      .rstudio <- attr(utils::getS3method("rxUiGet", .cls), "rstudio")
+      if (is.null(.rstudio)) {
+        return(list("calculated value"))
+      } else if (is.na(.rstudio)) {
+        # If it is NA, then return the value
+        return(rxUiGet(.obj))
+      } else {
+        return(.rstudio)
+      }
+    }
+  }
+  rxUiGet(.obj)
 }
 
 #' S3 for getting information from UI model
@@ -62,6 +86,7 @@ rxUiGet.levels <- function(x, ...) {
   }, character(1), USE.NAMES=FALSE),
   str2lang)
 }
+attr(rxUiGet.levels, "rstudio") <- quote(levels(a))
 
 #' @rdname rxUiGet
 #' @export
@@ -70,6 +95,7 @@ rxUiGet.state <- function(x, ...) {
   rxModelVars(.ui)$state
 }
 attr(rxUiGet.state, "desc") <- "states associated with the model (in order)"
+attr(rxUiGet.state, "rstudio") <- "state" # character
 
 #' @rdname rxUiGet
 #' @export
@@ -92,6 +118,7 @@ rxUiGet.stateDf <- function(x, ...) {
   }
 }
 attr(rxUiGet.stateDf, "desc") <- "states and cmt number data.frame"
+attr(rxUiGet.stateDf, "rstudio") <- NA # passthrough
 
 #' @export
 #' @rdname rxUiGet
@@ -123,6 +150,7 @@ rxUiGet.statePropDf <- function(x,...) {
                               "Property"=.props)
                  }))
 }
+attr(rxUiGet.statePropDf, "rstudio") <- NA
 
 #' @export
 #' @rdname rxUiGet
@@ -194,6 +222,7 @@ rxUiGet.theta <- function(x, ...) {
   setNames(.ini$est[.w], .ini$name[.w])
 }
 attr(rxUiGet.theta, "desc") <- "Initial Population/Fixed Effects estimates, theta"
+attr(rxUiGet.theta, "rstudio") <- c("theta"=1.0) # named vector
 
 #' @export
 #' @rdname rxUiGet
@@ -223,6 +252,7 @@ rxUiGet.omega <- function(x, ...) {
   .lotri
 }
 attr(rxUiGet.omega, "desc") <- "Initial Random Effects variability matrix, omega"
+attr(rxUiGet.omega, "rstudio") <- lotri::lotri(a+b ~ c(1, .1, 1))
 
 #' @export
 #' @rdname rxUiGet
@@ -230,6 +260,7 @@ rxUiGet.funTxt <- function(x, ...) {
   paste(rxUiGet.lstChr(x, ...), collapse="\n")
 }
 attr(rxUiGet.funTxt, "desc") <- "Get function text for the model({}) block"
+attr(rxUiGet.funTxt, "rstudio") <- "model text" # character
 
 #' @export
 #' @rdname rxUiGet
@@ -237,6 +268,7 @@ rxUiGet.allCovs <- function(x, ...) {
   get("covariates", envir=x[[1]])
 }
 attr(rxUiGet.allCovs, "desc") <- "Get all covariates defined in the model"
+attr(rxUiGet.allCovs, "rstudio") <- "covariates" # character
 
 #' @export
 #' @rdname rxUiGet
@@ -268,6 +300,7 @@ rxUiGet.muRefTable <- function(x, ...) {
   .muRef
 }
 attr(rxUiGet.muRefTable, "desc") <- "table of mu-referenced items in a model"
+attr(rxUiGet.muRefTable, "rstudio") <- NA # passthrough
 
 #' @rdname rxUiGet
 #' @export
@@ -295,7 +328,7 @@ rxUiGet.multipleEndpoint <- function(x, ...) {
   .info
 }
 attr(rxUiGet.multipleEndpoint, "desc") <- "table of multiple endpoint translations"
-
+attr(rxUiGet.multipleEndpoint, "rstudio") <- NA
 #' This is a generic function for deparsing certain objects when
 #' printing out a rxode2 object.  Currently it is used for any meta-information
 #'
@@ -377,6 +410,7 @@ rxUiGet.fun <- function(x, ...) {
   .ret2
 }
 attr(rxUiGet.fun, "desc") <- "Normalized model function"
+attr(rxUiGet.fun, "rstudio") <- function() {}
 
 #' @export
 #' @rdname rxUiGet
@@ -408,6 +442,7 @@ rxUiGet.md5 <- function(x, ...) {
   digest::digest(rxUiGet.funPartsDigest(x, ...), algo="md5")
 }
 attr(rxUiGet.md5, "desc") <- "MD5 hash of the UI model"
+attr(rxUiGet.md5, "rstudio") <- "md5 hash of the model"
 
 #' @export
 #' @rdname rxUiGet
@@ -415,6 +450,7 @@ rxUiGet.sha1 <- function(x, ...) {
   digest::digest(rxUiGet.funPartsDigest(x, ...), algo="sha1")
 }
 attr(rxUiGet.sha1, "desc") <- "SHA1 hash of the UI model"
+attr(rxUiGet.sha1, "rstudio") <- "sha1 hash of the model"
 
 sha1.rxUi <- function(x, digits = 14L, zapsmall = 7L, ..., algo = "sha1")  {
   digest::sha1(rxUiGet.funPartsDigest(list(x)),
@@ -427,6 +463,7 @@ rxUiGet.ini <- function(x, ...) {
   get("iniDf", x[[1]])
 }
 attr(rxUiGet.ini, "desc") <- "Model initilizations/bounds object"
+attr(rxUiGet.ini,"rstudio") <- NA
 
 #'@export
 #' @rdname rxUiGet
@@ -436,7 +473,7 @@ rxUiGet.iniFun <- function(x, ...) {
   lotri::lotriDataFrameToLotriExpression(.x$iniDf, useIni=TRUE)
 }
 attr(rxUiGet.iniFun, "desc") <- "normalized, quoted `ini()` block"
-
+attr(rxUiGet.iniFun, "rstudio") <- quote(ini({}))
 
 #' @export
 #' @rdname rxUiGet
@@ -445,6 +482,7 @@ rxUiGet.modelFun <- function(x, ...) {
   bquote(model(.(as.call(c(quote(`{`),.x$lstExpr)))))
 }
 attr(rxUiGet.modelFun, "desc") <- "normalized, quoted `model()` block"
+attr(rxUiGet.modelFun, "rstudio") <- quote(model({}))
 
 #' @export
 #' @rdname rxUiGet
@@ -457,12 +495,21 @@ rxUiGet.modelDesc <- function(x, ...) {
   .mv <- get("mv0", x[[1]])
   .mvL <- get("mvL", x[[1]])
   if (!is.null(.mvL)) {
+    # With the new linear models, need to remove anything from them
+    .rxUiLinCompartmentNames <-   c("depot",
+                                    "central",
+                                    "peripheral1",
+                                    "peripheral2")
+    .state <- .mvL$state[!(
+      (.mvL$state %in% .rxUiLinCompartmentNames) |
+      startsWith(.mvL$state, "rx__sens_")
+    )]
     return(sprintf(
       "rxode2-based solved PK %s-compartment model%s%s", .mvL$flags["ncmt"],
       ifelse(.mv$extraCmt == 2, " with first-order absorption", ""),
-      ifelse(length(.mvL$state) == 0L, "",
+      ifelse(length(.state) == 0L, "",
              sprintf(" mixed with free from %d-cmt ODE model",
-                     length(.mvL$state)))
+                     length(.state)))
     ))
   } else if (length(.mv$state) > 0) {
     return(sprintf("rxode2-based free-form %d-cmt ODE model", length(.mv$state)))
@@ -471,6 +518,7 @@ rxUiGet.modelDesc <- function(x, ...) {
   }
 }
 attr(rxUiGet.modelDesc, "desc") <- "Model description (ie linear compartment, pred, ode etc)"
+attr(rxUiGet.modelDesc, "rstudio") <- "model description"
 
 #' @export
 #' @rdname rxUiGet
@@ -481,6 +529,7 @@ rxUiGet.thetaLower <- function(x, ...) {
   setNames(.ini$lower[.w], .ini$name[.w])
 }
 attr(rxUiGet.thetaLower, "desc") <- "thetaLower"
+attr(rxUiGet.thetaLower, "rstudio") <- c("thetaLower"=1.0) # named vector
 
 #' @export
 #' @rdname rxUiGet
@@ -491,6 +540,7 @@ rxUiGet.thetaUpper <- function(x, ...) {
   setNames(.ini$upper[.w], .ini$name[.w])
 }
 attr(rxUiGet.thetaUpper, "desc") -> "thetaUpper"
+attr(rxUiGet.thetaUpper, "rstudio") <- c("thetaUpper"=1.0) # named vector
 
 #' @export
 #' @rdname rxUiGet
@@ -499,8 +549,16 @@ rxUiGet.lhsVar <- function(x, ...) {
   .eta <- get("etaLhsDf", .x)
   .theta <- get("thetaLhsDf", .x)
   .cov <- get("covLhsDf", .x)
-  setNames(c(.eta$eta, .theta$theta, .cov$cov),
-           c(.eta$lhs, .theta$lhs, .cov$lhs))
+  if (exists("levelLhsDf", .x)) {
+    .level <- get("levelLhsDf", .x)
+  } else {
+    .level <- list(level=character(0),
+                  lhs=character(0))
+  }
+  setNames(c(.eta$eta, .theta$theta, .cov$cov,
+             .level$level),
+           c(.eta$lhs, .theta$lhs, .cov$lhs,
+             .level$lhs))
 }
 
 #' @export
@@ -510,10 +568,19 @@ rxUiGet.varLhs <- function(x, ...) {
   .eta <- get("etaLhsDf", .x)
   .theta <- get("thetaLhsDf", .x)
   .cov <- get("covLhsDf", .x)
-  setNames(c(.eta$lhs, .theta$lhs, .cov$lhs),
-           c(.eta$eta, .theta$theta, .cov$cov))
+  if (exists("levelLhsDf", .x)) {
+    .level <- get("levelLhsDf", .x)
+  } else {
+    .level <- list(level=character(0),
+                   lhs=character(0))
+  }
+  setNames(c(.eta$lhs, .theta$lhs, .cov$lhs,
+             .level$lhs),
+           c(.eta$eta, .theta$theta, .cov$cov,
+             .level$level))
 }
 attr(rxUiGet.varLhs, "desc") <- "var->lhs translation"
+attr(rxUiGet.varLhs, "rstudio") <- c("varLhs"="lhs") # character
 
 #' @export
 #' @rdname rxUiGet
@@ -523,6 +590,7 @@ rxUiGet.lhsEta <- function(x, ...) {
   setNames(.eta$eta,.eta$lhs)
 }
 attr(rxUiGet.lhsEta, "desc") <- "lhs->eta translation"
+attr(rxUiGet.lhsEta, "rstudio") <- c("lhsEta"="eta") # character
 
 #' @export
 #' @rdname rxUiGet
@@ -532,6 +600,7 @@ rxUiGet.lhsTheta <- function(x, ...) {
   setNames(.eta$theta, .eta$lhs)
 }
 attr(rxUiGet.lhsTheta, "desc") <- "lhs->theta translation"
+attr(rxUiGet.lhsTheta, "rstudio") <- c("lhsTheta"="theta") # character
 
 #' @export
 #' @rdname rxUiGet
@@ -541,6 +610,7 @@ rxUiGet.lhsCov <- function(x, ...) {
   setNames(.cov$cov, .cov$lhs)
 }
 attr(rxUiGet.lhsCov, "desc") <- "lhs->cov translation"
+attr(rxUiGet.lhsCov, "rstudio") <- c("lhsCov"="cov") # character
 
 #' @export
 #' @rdname rxUiGet
@@ -550,6 +620,7 @@ rxUiGet.etaLhs <- function(x, ...) {
   setNames(.eta$lhs, .eta$eta)
 }
 attr(rxUiGet.etaLhs, "desc") <- "eta->lhs translation"
+attr(rxUiGet.etaLhs, "rstudio") <- c("etaLhs"="etaLhs") # character
 
 #' @export
 #' @rdname rxUiGet
@@ -559,6 +630,7 @@ rxUiGet.thetaLhs <- function(x, ...) {
   setNames(.theta$lhs, .theta$theta)
 }
 attr(rxUiGet.thetaLhs, "desc") <- "theta->lhs translation"
+attr(rxUiGet.thetaLhs, "rstudio") <- c("theta"="lhs")
 
 #' @export
 #' @rdname rxUiGet
@@ -568,6 +640,22 @@ rxUiGet.covLhs <- function(x, ...) {
   setNames(.cov$lhs, .cov$cov)
 }
 attr(rxUiGet.covLhs, "desc") <- "cov->lhs translation"
+attr(rxUiGet.covLhs, "rstudio") <- "covLhs" # character
+
+#' @export
+#' @rdname rxUiGet
+rxUiGet.levelLhs <- function(x, ...) {
+  .x <- x[[1]]
+  if (exists("levelLhsDf", .x)) {
+    .level <- get("levelLhsDf", .x)
+  } else {
+    .level <- list(level=character(0),
+                  lhs=character(0))
+  }
+  setNames(.level$lhs, .level$level)
+}
+attr(rxUiGet.levelLhs, "desc") <- "level->lhs translation"
+attr(rxUiGet.levelLhs, "rstudio") <- "levelLhs" # character
 
 #' @export
 #' @rdname rxUiGet
@@ -588,6 +676,24 @@ rxUiGet.default <- function(x, ...) {
                      "meta"="Model meta information",
                      "iniDf"="Initialization data frame for UI")
 
+.rxUiDevelop <- new.env(parent=emptyenv())
+.rxUiDevelop$enable <- FALSE
+
+#' rxUiDevelop - Enable/Disable rxUi development.  Here all $ completions are given
+#'
+#'
+#' @param enable boolean to enable/disable rxUi development mode.
+#' @return nothing, called for side effects
+#' @export
+#' @author Matthew L. Fidler
+#' @examples
+#'
+#' rxUiDevelop(TRUE)
+#' rxUiDevelop(FALSE)
+rxUiDevelop <- function(enable=TRUE) {
+  .rxUiDevelop$enable <- enable
+}
+
 .rxUiGetSupportedDollars <- function() {
   .v <- as.character(utils::methods("rxUiGet"))
   .v <- .v[.v != "rxUiGet.default"]
@@ -596,8 +702,20 @@ rxUiGet.default <- function(x, ...) {
   }, character(1), USE.NAMES=FALSE)
   .v <- vapply(.cls, function(cls) {
     .desc <- attr(utils::getS3method("rxUiGet", cls), "desc")
-    if (is.null(.desc)) .desc <- ""
-    .desc
+    if (is.null(.desc)) {
+      if (.rxUiDevelop$enable) {
+        .desc <- " "
+      } else {
+        .desc <- ""
+      }
+    }
+    if (is.character(.desc)) {
+      .desc
+    } else {
+      message("Bad description for rxUiGet method: ", cls,
+              " - should be character or NULL, got: ", class(.desc))
+      ""
+    }
   }, character(1), USE.NAMES=TRUE)
   # Take out any "hidden methods"
   .w <- which(.v != "")
